from setuptools import setup

setup(name='distributions_2',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions_2'],
      author= 'bayode',
      email='bayfag@yahoo.com',
      zip_safe=False)
